@@ -15,6 +15,7 @@ from suite_py.commands import ask_review
 from suite_py.commands import create_qa
 from suite_py.commands import delete_qa
 from suite_py.commands import status
+from suite_py.commands import check
 from suite_py.lib.handler import prompt_utils
 from suite_py.lib.config import Config
 from suite_py.__version__ import __version__
@@ -132,3 +133,9 @@ def cli_rollback(ctx):
 @click.pass_context
 def cli_status(ctx):
     status.entrypoint(ctx.obj["project"], ctx.obj["captainhook_timeout"])
+
+
+@main.command("check", help="Verifica autorizzazioni ai servizi di terze parti")
+@click.pass_context
+def cli_check(ctx):
+    check.entrypoint(ctx.obj["captainhook_timeout"])
