@@ -3,8 +3,6 @@ import readline
 import functools
 import sys
 
-from slack.errors import SlackClientError
-
 from suite_py.lib.config import Config
 from suite_py.lib.handler.youtrack_handler import YoutrackHandler
 from suite_py.lib.handler.github_handler import GithubHandler
@@ -17,6 +15,7 @@ youtrack = YoutrackHandler()
 github = GithubHandler()
 logger = Logger()
 slack = SlackHandler()
+config = Config()
 
 
 def maybe_get_users_list(timeout):
@@ -24,13 +23,14 @@ def maybe_get_users_list(timeout):
         captainhook = CaptainHook()
         if timeout:
             captainhook.set_timeout(timeout)
-        return captainhook.get_users_list().json()
-    except:
-        logger.error(
-            "Non riesco ad ottenere la lista degli utenti da captainhook.\
-            Controlla di avere attiva la VPN. Se il problema persiste aggiungi i reviewer dal sito GitHub")
-        sys.exit(-1)
-config = Config().load()
+        users = captainhook.get_users_list().json()
+        config.put_cache("users", users)
+        return users
+    except Exception:
+        logger.warning(
+            "Non riesco ad ottenere la lista degli utenti da captainhook. Utilizzo la versione in cache."
+        )
+        return config.get_cache("users")
 
 
 def get_pr(project):
@@ -39,11 +39,11 @@ def get_pr(project):
 
     if pull.totalCount:
         pr = pull[0]
-        logger.info('Ho trovato la pull request numero {} per il branch {} sul repo {}'.format(
-            pr.number, branch_name, project))
+        logger.info(
+            f"Ho trovato la pull request numero {pr.number} per il branch {branch_name} sul repo {project}"
+        )
     else:
-        logger.error(
-            'Nessuna pull request aperta trovata per il branch {}'.format(branch_name))
+        logger.error(f"Nessuna pull request aperta trovata per il branch {branch_name}")
         sys.exit(-1)
 
     return pr
@@ -57,18 +57,20 @@ def ask_reviewer(users):
     youtrack_reviewers = []
 
     youtrack_reviewers = list(
-        input("Scegli i reviewers (nome.cognome - separati da spazio - premere TAB per autocomplete) > ").split())
+        input(
+            "Scegli i reviewers (nome.cognome - separati da spazio - premere TAB per autocomplete) > "
+        ).split()
+    )
 
-    if len(youtrack_reviewers) < 1:
+    if not youtrack_reviewers:
         logger.warning("Devi inserire almeno un reviewer")
         return ask_reviewer(users)
-    else:
-        return youtrack_reviewers
+
+    return youtrack_reviewers
 
 
 def completer(users, text, state):
-    options = [x["youtrack"]
-               for x in users if text.lower() in x["youtrack"].lower()]
+    options = [x["youtrack"] for x in users if text.lower() in x["youtrack"].lower()]
     try:
         return options[state]
     except IndexError:
@@ -78,16 +80,9 @@ def completer(users, text, state):
 def maybe_send_slack_message(slack_reviewers, url):
     revs = ""
     for rev in slack_reviewers:
-        revs += "<@{}> ".format(rev)
+        revs += f"<@{rev}> "
 
-    try:
-        slack.post(config['user']['notify_channel'], '{}{}'.format(
-            revs, url))
-
-        logger.info('Cito reviewers su Slack')
-    except SlackClientError as e:
-        logger.error("Errore di invio messaggio a Slack:\n{}".format(e))
-        sys.exit(-1)
+    slack.post("review_channel", f"{revs}{url}")
 
 
 def find_github_and_slack_nicks(youtrack_reviewers, users):
@@ -107,18 +102,19 @@ def maybe_adjust_youtrack_card(title, youtrack_reviewers):
 
     if youtrack_id:
         logger.info(
-            'Sposto la card {} in review su youtrack e aggiungo i tag degli utenti'.format(youtrack_id))
-        youtrack.update_state(youtrack_id, 'Review')
+            f"Sposto la card {youtrack_id} in review su youtrack e aggiungo i tag degli utenti"
+        )
+        youtrack.update_state(youtrack_id, "Review")
         for rev in youtrack_reviewers:
             try:
-                youtrack.add_tag(youtrack_id, "review:{}".format(rev))
+                youtrack.add_tag(youtrack_id, f"review:{rev}")
             except BaseException as e:
-                logger.warning(
-                    "Non sono riuscito ad aggiungere i tag di review: {}".format(e))
+                logger.warning(f"Non sono riuscito ad aggiungere i tag di review: {e}")
                 sys.exit(-1)
     else:
         logger.warning(
-            'Reviewers inseriti SOLO su GitHub. Nessuna card collegata o card nel nome del branch inesistente su YouTrack.')
+            "Reviewers inseriti SOLO su GitHub. Nessuna card collegata o card nel nome del branch inesistente su YouTrack."
+        )
 
 
 def entrypoint(project, timeout):
@@ -129,6 +125,6 @@ def entrypoint(project, timeout):
         youtrack_reviewers, users
     )
     pr.create_review_request(github_reviewers)
-    logger.info('Aggiungo reviewers su GitHub')
+    logger.info("Aggiungo reviewers su GitHub")
     maybe_send_slack_message(slack_reviewers, pr.html_url)
     maybe_adjust_youtrack_card(pr.title, youtrack_reviewers)
