@@ -60,24 +60,26 @@ def entrypoint(project, timeout):
 
     deployed_cards_link = []
     issue_ids = youtrack.get_issue_ids(commits)
-    update_youtrack_state = prompt_utils.ask_confirm(
-        f"Vuoi spostare le card associate in {release_state}?", default=False
-    )
 
-    for issue_id in issue_ids:
-        try:
-            deployed_cards_link.append(youtrack.get_link(issue_id))
-            youtrack.comment(
-                issue_id,
-                f"Deploy in produzione di {project} effettuato con la release {new_version}",
-            )
-            if update_youtrack_state:
-                youtrack.update_state(issue_id, release_state)
-                logger.info(f"{issue_id} spostata in {release_state}")
-        except Exception:
-            logger.warning(
-                f"Si è verificato un errore durante lo spostamento della card {issue_id} in {release_state}"
-            )
+    if len(issue_ids) > 0:
+        update_youtrack_state = prompt_utils.ask_confirm(
+            f"Vuoi spostare le card associate in {release_state}?", default=False
+        )
+
+        for issue_id in issue_ids:
+            try:
+                deployed_cards_link.append(youtrack.get_link(issue_id))
+                youtrack.comment(
+                    issue_id,
+                    f"Deploy in produzione di {project} effettuato con la release {new_version}",
+                )
+                if update_youtrack_state:
+                    youtrack.update_state(issue_id, release_state)
+                    logger.info(f"{issue_id} spostata in {release_state}")
+            except Exception:
+                logger.warning(
+                    f"Si è verificato un errore durante lo spostamento della card {issue_id} in {release_state}"
+                )
 
     create_release(repo, new_version, message, project, deployed_cards_link)
 
@@ -103,10 +105,7 @@ def create_release(repo, new_version, message, project, deployed_cards_link):
     if new_release:
         logger.info(f"La release è stata creata! Link: {new_release.html_url}")
 
-        slack.post(
-            "deploy_channel",
-            f"Ho effettuato il deploy di {project}. Nuova release con versione {new_version} {new_release.html_url}\n{deployed_cards_to_string(deployed_cards_link)}",
-        )
+        post_on_slack(project, new_release, new_version, deployed_cards_link)
 
         drone_url = drone.get_last_build_url(project)
         if drone_url:
@@ -127,6 +126,20 @@ def deployed_cards_to_string(cards):
     return ""
 
 
+def post_on_slack(project, new_release, new_version, deployed_cards_link):
+    with Halo(text="Scrivo su Slack...", spinner="dots", color="magenta"):
+        response = slack.post(
+            "deploy_channel",
+            f"Ho effettuato il deploy di {project}. Nuova release con versione <{new_release.html_url}|{new_version}>",
+        )
+        if response is not None and len(deployed_cards_link) > 0:
+            slack.reply_thread(
+                "deploy_channel",
+                response["ts"],
+                deployed_cards_to_string(deployed_cards_link),
+            )
+
+
 def check_migrations_deploy(commits):
     if not commits:
         logger.error("ERRORE: nessun commit trovato")
