@@ -42,6 +42,9 @@ class CaptainHook(metaclass=Singleton):
             f"/projects/check?project={project}&environment={env}"
         )
 
+    def check(self):
+        return requests.get(f"{self._baseurl}/", timeout=(2, self._timeout))
+
     def get_users_list(self):
         return self.send_get_request("/users/all")
 
